import { TerminalStage } from '../../stages';
class AverageCollector extends TerminalStage {
    _sum = 0;
    _totalElement = 0;
    consume(element) {
        this._throwErrorIfNotNumber(element);
        this._sum += element;
        this._totalElement++;
    }
    _throwErrorIfNotNumber(value) {
        if (typeof value !== 'number') {
            throw new Error(`[average() collector] Numbers expected, erroneous pipeline element received was ${JSON.stringify(value)}`);
        }
    }
    get() {
        if (this._totalElement > 0) {
            return this._sum / this._totalElement;
        }
        throw new Error('[average() collector] Pipeline contains 0 elements');
    }
}
/**
 * Return a terminal stage that calculates the average of all numeric elements in the pipeline.
 * This collector throws an error if at least one element is not numeric.
 *
 * @template IN The type parameter of each incoming element in the pipeline.
 */
export function average() {
    return new AverageCollector();
}
//# sourceMappingURL=average.js.map