import { TerminalStage } from '../../stages';
class NoneMatchCollector extends TerminalStage {
    _predicate;
    _noneMatch = true;
    constructor(_predicate) {
        super();
        this._predicate = _predicate;
    }
    consume(element) {
        this._noneMatch = !this._predicate(element);
        if (!this._noneMatch) {
            this.broadcast("TERMINATE_EARLY" /* PipelineEvent.TERMINATE_EARLY */);
        }
    }
    get() {
        return this._noneMatch;
    }
}
/**
 * Return a terminal stage that checks whether no elements in this pipeline match the provided predicate.
 *
 * @param predicate The predicate used to test if no elements of the pipeline match.
 *
 * @template IN The type parameter of each incoming element in the pipeline.
 *
 * @returns
 */
export function noneMatch(predicate) {
    return new NoneMatchCollector(predicate);
}
//# sourceMappingURL=noneMatch.js.map