import { IntermediateStage } from '../../stages';
class DropWhileStage extends IntermediateStage {
    _predicate;
    constructor(_predicate) {
        super();
        this._predicate = _predicate;
    }
    consume(element, hasMoreDataUpstream) {
        const shouldKeepDropping = this._predicate(element);
        if (!shouldKeepDropping) {
            this._downstream.consume(element, hasMoreDataUpstream);
            this.broadcast("DETACH_STAGE" /* PipelineEvent.DETACH_STAGE */);
        }
    }
}
/**
 * Return an intermediate stage that discards elements from the pipeline as long as the provided predicate is `true`.
 * As soon as the predicate returns `false`, this stage will no longer execute even if the predicate returns `true`
 * for subsequent elements down the pipeline.
 *
 * @param predicate
 *
 * @template IN The type parameter of each incoming element in the pipeline.
 *
 * @returns
 */
export function dropWhile(predicate) {
    return new DropWhileStage(predicate);
}
//# sourceMappingURL=dropWhile.js.map