import { IntermediateStage } from '../../stages';
class LimitStage extends IntermediateStage {
    _limit;
    _seenElementCount = 0;
    constructor(_limit) {
        super();
        this._limit = _limit;
    }
    consume(element, hasMoreDataUpstream) {
        if (this._seenElementCount < this._limit) {
            this._downstream.consume(element, hasMoreDataUpstream);
            this._seenElementCount++;
        }
        if (this._seenElementCount === this._limit) {
            this.broadcast("TERMINATE_EARLY" /* PipelineEvent.TERMINATE_EARLY */);
        }
    }
    reset() {
        this._seenElementCount = 0;
        super.reset();
    }
}
/**
 * Return an intermediate stage that only allows a fixed number of elements through the pipeline.
 *
 * @param value The number of elements allowed to flow through the pipeline.
 *
 * @template IN The type parameter of each incoming element in the pipeline.
 *
 * @returns
 */
export function limit(value) {
    if (value < 0) {
        throw new Error(`[limit() operator] Must be greater than or equal to 0, erroneous pipeline element received was ${value}`);
    }
    return new LimitStage(value);
}
//# sourceMappingURL=limit.js.map