import { IntermediateStage } from '../../stages';
class SkipStage extends IntermediateStage {
    _skipCount;
    _skippedElementCount = 0;
    constructor(_skipCount) {
        super();
        this._skipCount = _skipCount;
    }
    consume(element, hasMoreDataUpstream) {
        this._skippedElementCount++;
        if (this._skippedElementCount === this._skipCount) {
            this.broadcast("DETACH_STAGE" /* PipelineEvent.DETACH_STAGE */);
        }
        else if (this._skipCount === 0) {
            this._downstream.consume(element, hasMoreDataUpstream);
        }
    }
    reset() {
        this._skippedElementCount = 0;
        super.reset();
    }
}
/**
 * Return an intermediate stage that skips over a fixed number of elements.
 *
 * @param count The number of elements to skip over.
 *
 * @template IN The type parameter of each incoming element in the pipeline.
 *
 * @returns
 */
export function skip(count) {
    if (count < 0) {
        throw new Error(`[skip() operator] Must be greater than or equal to 0, erroneous pipeline element received was ${count}`);
    }
    return new SkipStage(count);
}
//# sourceMappingURL=skip.js.map