import { IntermediateStage } from '../../stages';
class SortedStage extends IntermediateStage {
    _comparator;
    _accumulator = [];
    constructor(_comparator) {
        super();
        this._comparator = _comparator;
    }
    consume(element, hasMoreDataUpstream) {
        this._accumulator.push(element);
        if (!hasMoreDataUpstream) {
            this._accumulator.sort(this._comparator);
            const totalElementCount = this._accumulator.length;
            for (let index = 0; index < totalElementCount; index++) {
                this._downstream.consume(this._accumulator[index], index !== totalElementCount - 1);
            }
        }
    }
    reset() {
        this._accumulator = [];
        super.reset();
    }
}
/**
 * Return an intermediate stage that sorts the elements in this pipeline. This stage will accumulate all
 * the elements before performing the sort, after that, it will resuming the pipeline by sending the
 * sorted elements down the pipeline.
 *
 * If no comparator function is provided, then the sorting behavior is the same as that of `Array.prototype.sort`
 * where elements are compared by their character code points, otherwise, sorting behavior is dictated by the
 * provided comparator where a returned value of `-1` indicates that the left element should come before the
 * right element, `1` indicates that the left element should come after the right element, and `0` indicates equality.
 *
 * @param comparator The comparator function to sort by.
 *
 * @template IN The type parameter of each incoming element in the pipeline.
 *
 * @returns
 */
export function sorted(comparator) {
    return new SortedStage(comparator);
}
//# sourceMappingURL=sorted.js.map