import { IntermediateStage } from '../../stages';
class TakeWhileStage extends IntermediateStage {
    _predicate;
    constructor(_predicate) {
        super();
        this._predicate = _predicate;
    }
    consume(element, hasMoreDataUpstream) {
        const shouldKeepTaking = this._predicate(element);
        if (shouldKeepTaking) {
            this._downstream.consume(element, hasMoreDataUpstream);
        }
        else {
            this.broadcast("TERMINATE_EARLY" /* PipelineEvent.TERMINATE_EARLY */);
        }
    }
}
/**
 * Return an intermediate stage that consumes elements in the pipeline as long as the provided predicate is `true`.
 * As soon as the predicate returns `false`, this stage will no longer execute even if the predicate returns `true`
 * for subsequent elements down the pipeline.
 *
 * @param predicate
 *
 * @template IN The type parameter of each incoming element in the pipeline.
 *
 * @returns
 */
export function takeWhile(predicate) {
    return new TakeWhileStage(predicate);
}
//# sourceMappingURL=takeWhile.js.map